@@ -329,6 +329,7 @@ service SpecialFieldsModelController {
     rpc Update(SpecialFieldsModelRequest) returns (SpecialFieldsModelResponse) {}
 }
 
+// Test comment for whole message
 message CustomRetrieveResponseSpecialFieldsModelResponse {
     string uuid = 1;
     int32 default_method_field = 2;
@@ -347,6 +348,8 @@ message SpecialFieldsModelListResponse {
     int32 count = 2;
 }
 
+// Special Fields Model
+// with two lines comment
 message SpecialFieldsModelPartialUpdateRequest {
     string uuid = 1;
     repeated string _partial_update_fields = 2;
@@ -354,12 +357,16 @@ message SpecialFieldsModelPartialUpdateRequest {
     repeated int32 list_datas = 4;
 }
 
+// Special Fields Model
+// with two lines comment
 message SpecialFieldsModelRequest {
     string uuid = 1;
     google.protobuf.Struct meta_datas = 2;
     repeated int32 list_datas = 3;
 }
 
+// Special Fields Model
+// with two lines comment
 message SpecialFieldsModelResponse {
     string uuid = 1;
     google.protobuf.Struct meta_datas = 2;
@@ -443,10 +450,10 @@ message BasicParamWithSerializerListRequest {
 }
 
 message BasicParamWithSerializerRequest {
-    //@test=comment1
-    //@test2=comment2
+    // @test=comment1
+    // @test2=comment2
     string user_name = 1;
-    //@test=test_in_serializer
+    // @test=test_in_serializer
     google.protobuf.Struct user_data = 2;
     string user_password = 3;
     bytes bytes_example = 4;
@@ -476,10 +483,10 @@ message BasicServiceListResponse {
 }
 
 message BasicServiceRequest {
-    //@test=comment1
-    //@test2=comment2
+    // @test=comment1
+    // @test2=comment2
     string user_name = 1;
-    //@test=test_in_serializer
+    // @test=test_in_serializer
     google.protobuf.Struct user_data = 2;
     string user_password = 3;
     bytes bytes_example = 4;
@@ -487,10 +494,10 @@ message BasicServiceRequest {
 }
 
 message BasicServiceResponse {
-    //@test=comment1
-    //@test2=comment2
+    // @test=comment1
+    // @test2=comment2
     string user_name = 1;
-    //@test=test_in_serializer
+    // @test=test_in_serializer
     google.protobuf.Struct user_data = 2;
     bytes bytes_example = 3;
     repeated google.protobuf.Struct list_of_dict = 4;
@@ -506,7 +513,7 @@ message CustomMixParamForRequest {
 }
 
 message CustomNameForRequest {
-    //@test=in_decorator
+    // @test=in_decorator
     string user_name = 1;
 }
 
@@ -565,6 +572,10 @@ service SpecialFieldsModelController {
     rpc Update(SpecialFieldsModel) returns (SpecialFieldsModel) {}
 }
 
+service StreamInController {
+    rpc StreamIn(stream StreamInStreamInRequest) returns (StreamInStreamInListResponse) {}
+}
+
 service SyncUnitTestModelController {
     rpc Create(UnitTestModel) returns (UnitTestModel) {}
     rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
@@ -625,10 +636,10 @@ message BasicMixParamWithSerializerListResponse {
 }
 
 message BasicParamWithSerializerRequest {
-    //@test=comment1
-    //@test2=comment2
+    // @test=comment1
+    // @test2=comment2
     string user_name = 1;
-    //@test=test_in_serializer
+    // @test=test_in_serializer
     google.protobuf.Struct user_data = 2;
     string user_password = 3;
     bytes bytes_example = 4;
@@ -652,10 +663,10 @@ message BasicProtoListChildListResponse {
 }
 
 message BasicService {
-    //@test=comment1
-    //@test2=comment2
+    // @test=comment1
+    // @test2=comment2
     string user_name = 1;
-    //@test=test_in_serializer
+    // @test=test_in_serializer
     google.protobuf.Struct user_data = 2;
     string user_password = 3;
     bytes bytes_example = 4;
@@ -677,7 +688,7 @@ message CustomMixParamForRequestList {
 }
 
 message CustomNameForRequest {
-    //@test=in_decorator
+    // @test=in_decorator
     string user_name = 1;
 }
 
@@ -685,6 +696,7 @@ message CustomNameForResponse {
     string user_name = 1;
 }
 
+// Test comment for whole message
 message CustomRetrieveResponseSpecialFieldsModel {
     string uuid = 1;
     int32 default_method_field = 2;
@@ -765,6 +777,8 @@ message RelatedFieldModelRetrieveRequest {
     string uuid = 1;
 }
 
+// Special Fields Model
+// with two lines comment
 message SpecialFieldsModel {
     string uuid = 1;
     google.protobuf.Struct meta_datas = 2;
@@ -784,6 +798,8 @@ message SpecialFieldsModelListResponse {
     int32 count = 2;
 }
 
+// Special Fields Model
+// with two lines comment
 message SpecialFieldsModelPartialUpdateRequest {
     string uuid = 1;
     repeated string _partial_update_fields = 2;
@@ -796,6 +812,19 @@ message SpecialFieldsModelRetrieveRequest {
     string uuid = 1;
 }
 
+message StreamInStreamInListResponse {
+    repeated StreamInStreamInResponse results = 1;
+    int32 count = 2;
+}
+
+message StreamInStreamInRequest {
+    string name = 1;
+}
+
+message StreamInStreamInResponse {
+    int32 count = 1;
+}
+
 message SyncUnitTestModelListWithExtraArgsRequest {
     bool archived = 1;
 }
@@ -892,6 +921,10 @@ service SpecialFieldsModelController {
     rpc Update(SpecialFieldsModelRequest) returns (SpecialFieldsModelResponse) {}
 }
 
+service StreamInController {
+    rpc StreamIn(stream StreamInStreamInRequest) returns (StreamInStreamInListResponse) {}
+}
+
 service SyncUnitTestModelController {
     rpc Create(UnitTestModelRequest) returns (UnitTestModelResponse) {}
     rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
@@ -963,10 +996,10 @@ message BasicParamWithSerializerListRequest {
 }
 
 message BasicParamWithSerializerRequest {
-    //@test=comment1
-    //@test2=comment2
+    // @test=comment1
+    // @test2=comment2
     string user_name = 1;
-    //@test=test_in_serializer
+    // @test=test_in_serializer
     google.protobuf.Struct user_data = 2;
     string user_password = 3;
     bytes bytes_example = 4;
@@ -996,10 +1029,10 @@ message BasicServiceListResponse {
 }
 
 message BasicServiceRequest {
-    //@test=comment1
-    //@test2=comment2
+    // @test=comment1
+    // @test2=comment2
     string user_name = 1;
-    //@test=test_in_serializer
+    // @test=test_in_serializer
     google.protobuf.Struct user_data = 2;
     string user_password = 3;
     bytes bytes_example = 4;
@@ -1007,10 +1040,10 @@ message BasicServiceRequest {
 }
 
 message BasicServiceResponse {
-    //@test=comment1
-    //@test2=comment2
+    // @test=comment1
+    // @test2=comment2
     string user_name = 1;
-    //@test=test_in_serializer
+    // @test=test_in_serializer
     google.protobuf.Struct user_data = 2;
     bytes bytes_example = 3;
     repeated google.protobuf.Struct list_of_dict = 4;
@@ -1026,7 +1059,7 @@ message CustomMixParamForRequest {
 }
 
 message CustomNameForRequest {
-    //@test=in_decorator
+    // @test=in_decorator
     string user_name = 1;
 }
 
@@ -1034,6 +1067,7 @@ message CustomNameForResponse {
     string user_name = 1;
 }
 
+// Test comment for whole message
 message CustomRetrieveResponseSpecialFieldsModelResponse {
     string uuid = 1;
     int32 default_method_field = 2;
@@ -1140,6 +1174,8 @@ message SpecialFieldsModelListResponse {
     int32 count = 2;
 }
 
+// Special Fields Model
+// with two lines comment
 message SpecialFieldsModelPartialUpdateRequest {
     string uuid = 1;
     repeated string _partial_update_fields = 2;
@@ -1147,12 +1183,16 @@ message SpecialFieldsModelPartialUpdateRequest {
     repeated int32 list_datas = 4;
 }
 
+// Special Fields Model
+// with two lines comment
 message SpecialFieldsModelRequest {
     string uuid = 1;
     google.protobuf.Struct meta_datas = 2;
     repeated int32 list_datas = 3;
 }
 
+// Special Fields Model
+// with two lines comment
 message SpecialFieldsModelResponse {
     string uuid = 1;
     google.protobuf.Struct meta_datas = 2;
@@ -1164,6 +1204,19 @@ message SpecialFieldsModelRetrieveRequest {
     string uuid = 1;
 }
 
+message StreamInStreamInListResponse {
+    repeated StreamInStreamInResponse results = 1;
+    int32 count = 2;
+}
+
+message StreamInStreamInRequest {
+    string name = 1;
+}
+
+message StreamInStreamInResponse {
+    int32 count = 1;
+}
+
 message SyncUnitTestModelListWithExtraArgsRequest {
     bool archived = 1;
 }
